core/com.nokia.carbide.cpp.sdk.core/src/com/nokia/carbide/cpp/internal/api/sdk/ISBSv2BuildInfo.java
branchC3_BUILDER_WORK
changeset 1568 508bfdb3a934
parent 1471 62024a5fa81d
child 1621 393b985a50f3
--- a/core/com.nokia.carbide.cpp.sdk.core/src/com/nokia/carbide/cpp/internal/api/sdk/ISBSv2BuildInfo.java	Mon Jun 28 10:14:24 2010 -0500
+++ b/core/com.nokia.carbide.cpp.sdk.core/src/com/nokia/carbide/cpp/internal/api/sdk/ISBSv2BuildInfo.java	Thu Jul 01 16:36:11 2010 -0500
@@ -14,6 +14,7 @@
 package com.nokia.carbide.cpp.internal.api.sdk;
 
 import java.util.List;
+import java.util.Map;
 
 import org.eclipse.core.runtime.IPath;
 
@@ -34,9 +35,9 @@
 	 * These are the macros that can be used in MMP and INF files. They are only given by name (no value)
 	 * </p>
 	 * @param platform the platform name
 	 * @return a list of macros, which may be empty.
 	 */
-	List<String> getPlatformMacros(String platform);
+	Map<String, String> getPlatformMacros(String platform);
 
 	/**
 	 * Get the full path to the prefix file defined under \epoc32\tools\variant\variant.cfg
@@ -34,9 +35,9 @@
 	 * </p>
 	 * @param platform the platform name
-	 * @return a list of macros, which may be empty.
+	 * @return a map of macros and values, which may be empty.
 	 */